@@ -10,11 +10,9 @@ if IS_RELEASE:
     build_path = os.path.join(absolute_path, "frontend/build")
     _component_func = components.declare_component("stepper_bar", path=build_path)
 else:
-    _component_func = components.declare_component("stepper_bar", url="http://localhost:3001")
+    _component_func = components.declare_component("stepper_bar", url="http://localhost:3000")
 
 
-def stepper_bar(steps: List[str]) -> CustomComponent:
-    component_value = _component_func(steps=steps, default=0)
-    if component_value is None:
-        return 0
+def stepper_bar(steps: List[str], is_vertical: bool = False) -> CustomComponent:
+    component_value = _component_func(steps=steps, is_vertical=is_vertical, default=0)
     return component_value
